﻿Public Class RPwsp2dof
  '--------------------------------------------------------------------------
  '
  '       PLOT CALCULATION RESULT by PWSP2DOF.C
  '
  '            < RPWSP2DOF.BAS >
  '
  '       2012. 5. 6  CREATED BY N. IWATSUKI
  '       2021. 4. 4 CONVERTED BY N. IWATSUKI
  '
  '--------------------------------------------------------------------------
  '
  Public Pagemax As Integer = 1 ' Number of pages
  Dim STUDENT_NAME As String ' Student's name
  Dim PROGRAM_NAME As String ' Program name
  Dim X0, Y0, X4, Y4 As Double
  Dim L(4) As Double ' Link lengths
  Dim GSI, ETA As Double ' Position of output point
  Dim XPMIN, XPMAX, YPMIN, YPMAX As Double  'Range to search workspace
  Dim NX, NY As Integer 'Resolution to search workspace
  Dim NDMAX As Integer 'Maximum number to search workspace
  Dim THE(60000, 2) As Double ' Joint angles
  Dim XP(60000), YP(60000) As Double ' Position of output point
  '
  Private Sub Exe()
    Dim i As Integer
    '
    If P_page = 1 Then GoTo PAGE1
    '
PAGE1:
    FileOpen(1, "../../../PWSP2DOF.DAT", OpenMode.Input)
    Input(1, STUDENT_NAME)
    Input(1, PROGRAM_NAME)
    Input(1, X0) : Input(1, Y0)
    Input(1, X4) : Input(1, Y4)
    Input(1, L(0)) : Input(1, L(1)) : Input(1, L(2)) : Input(1, L(3))
    Input(1, GSI) : Input(1, ETA)
    Input(1, XPMIN) : Input(1, XPMAX) : Input(1, NX)
    Input(1, YPMIN) : Input(1, YPMAX) : Input(1, NY)
    NDMAX = (NX + 1) * (NY + 1)
    NDPLOT = 0
    '
    For i = 1 To NDMAX Step 1
      Input(1, XP(i)) : Input(1, YP(i)) : Input(1, THE(i, 0)) : Input(1, THE(i, 1))
      If XP(i) < -900.0 Then GoTo REND
      NDPLOT = NDPLOT + 1
    Next i
REND:
    FileClose(1)
    '
    PLOTS(graph) 'Plot start
    Phead() ' Plot header
    PXSYMBOL = 1.0 : PYSYMBOL = 16.0
    SYMBOL = "Workspace"
    PSYMBOL(graph) ' Plot string
    '
    X0PLOT = 2.0 : Y0PLOT = 0.5 ' Position of origin
    XSPLOT = 0.0 : YSPLOT = 0.0 ' Start position of axes
    XFPLOT = 20.0 : YFPLOT = 14.0 ' Final position of axes
    NXPLOT = 10 : NYPLOT = 7 ' Resolution of axes
    NVXPLOT = 1 : NVYPLOT = 1 ' Distance of value plot
    NDXPLOT = 1 : NDYPLOT = 1 ' Digit of values
    XMINPLOT = -0.4 : YMINPLOT = -0.2 ' Minimum values of axes
    XMAXPLOT = 0.6 : YMAXPLOT = 0.5 ' Maximum values of axes
    XANAME = "X m" : YANAME = "Y m" ' Name of axes
    PSCALE() ' Scaling
    For i = 1 To NDPLOT Step 1
      XPLOT(i) = XP(i)
      YPLOT(i) = YP(i)
    Next i
    GAXES(graph) ' Axes plot
    NUMPEN = 2 ' Pen number
    CPLOTSMALL(graph) ' Solid line plot
    '
    GoTo PEND

PEND:
    P_RELEASE()
  End Sub
  Private Sub Phead()
    PLOTDATE(graph)
    PLOTTIME(graph)
    PXSYMBOL = 10.0
    PYSYMBOL = 17.5
    SYMBOL = STUDENT_NAME
    PSYMBOL(graph)
    '
    PXSYMBOL = 1.0
    PYSYMBOL = 17.0
    SYMBOL = "Workspace Analysis of Planar Parallel Manipulator"
    PSYMBOL(graph)
    '
    PXSYMBOL = 3.0
    PYSYMBOL = 16.5
    SYMBOL = "with 2 DOF by PWSP2DOF.BAS"
    PSYMBOL(graph)
    '
    PXSYMBOL = 7.0
    PYSYMBOL = 16.0
    SYMBOL = "L_0@=" + Str$(L(0)) + ", L_1@=" + Str$(L(1)) + ", L_2@=" + Str$(L(2)) + ", L_3@=" + Str$(L(3))
    PSYMBOL(graph)
  End Sub
  Private Sub P_INITIALIZE()
    PictureBox1.Image = New Bitmap(PictureBox1.ClientRectangle.Width, PictureBox1.ClientRectangle.Height)
    graph = Graphics.FromImage(PictureBox1.Image)
    graphIsCreated = False
  End Sub
  Private Sub P_RELEASE()
    graph.Dispose()
    graphIsCreated = True
  End Sub
  Private Sub Run_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Run.Click
    If graphIsCreated = True Then
      P_INITIALIZE()
      P_page = 1
      Exe()
    End If
  End Sub
  Private Sub NextP_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles NextP.Click
    If graphIsCreated = True Then
      P_INITIALIZE()
      P_page = P_page + 1
      If P_page > Pagemax Then P_page = Pagemax
      Exe()
    End If
  End Sub
  Private Sub PrevP_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles PrevP.Click
    P_INITIALIZE()
    P_page = P_page - 1
    If P_page <= 0 Then P_page = 1
    Exe()
  End Sub
  Private Sub SaveG_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles SaveG.Click
    Dim fileName As String
    If graphIsCreated = True Then
      If SaveFileDialog1.ShowDialog() = Windows.Forms.DialogResult.OK Then
        fileName = SaveFileDialog1.FileName
      Else
        Exit Sub
      End If
      PictureBox1.Image.Save(fileName, Imaging.ImageFormat.Bmp)
      MessageBox.Show("Saved in " + fileName)
    End If
  End Sub
  Private Sub PrintG_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles PrintG.Click
    If graphIsCreated = True Then
      Dim pd As New System.Drawing.Printing.PrintDocument
      AddHandler pd.PrintPage, AddressOf pd_PrintPage
      Dim pdlg As New PrintDialog
      pdlg.Document = pd
      If pdlg.ShowDialog() = DialogResult.OK Then
        pd.Print()
      End If
    End If
  End Sub
  Private Sub pd_PrintPage(ByVal sender As Object, ByVal e As System.Drawing.Printing.PrintPageEventArgs)
    e.Graphics.DrawImage(PictureBox1.Image, 0, 0)
  End Sub

  Private Sub PictureBox1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles PictureBox1.Click

  End Sub
End Class
